@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -34,28 +34,33 @@
 #include <QUrl>
 #include <QVBoxLayout>
 #include <QWindow>
+
+#include <KAboutData>
+#include <KHelpMenu>
+
 namespace
 {
 constexpr char KDebugSettingsDialogGroupName[] = "KDebugSettingsDialog";
 }
 KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     : QDialog(parent)
+    , mTabWidget(new QTabWidget(this))
+    , mKdeApplicationSettingsPage(new KDEApplicationDebugSettingPage(this))
+    , mCustomSettingsPage(new CustomDebugSettingsPage(this))
+    , mEnvironmentSettingsRulesPage(new EnvironmentSettingsRulesPage(this))
+    , mCategoryWarning(new CategoryWarning(this))
+    , mLoadToolButton(new LoadToolButton(this))
 {
     auto mainLayout = new QVBoxLayout(this);
 
-    mCategoryWarning = new CategoryWarning(this);
     mCategoryWarning->setObjectName(QStringLiteral("categorywarning"));
     mainLayout->addWidget(mCategoryWarning);
 
-    mTabWidget = new QTabWidget(this);
     mTabWidget->setObjectName(QStringLiteral("tabwidget"));
     mainLayout->addWidget(mTabWidget);
 
-    mKdeApplicationSettingsPage = new KDEApplicationDebugSettingPage(this);
     mKdeApplicationSettingsPage->setObjectName(QStringLiteral("kdeapplicationsettingspage"));
-    mCustomSettingsPage = new CustomDebugSettingsPage(this);
     mCustomSettingsPage->setObjectName(QStringLiteral("customsettingspage"));
-    mEnvironmentSettingsRulesPage = new EnvironmentSettingsRulesPage(this);
     mEnvironmentSettingsRulesPage->setObjectName(QStringLiteral("environmentsettingsrulespage"));
     mTabWidget->addTab(mKdeApplicationSettingsPage, i18n("KDE Application"));
     mTabWidget->addTab(mCustomSettingsPage, i18n("Custom Rules"));
@@ -74,7 +79,6 @@ KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     connect(saveAs, &SaveToolButton::saveAsFile, this, &KDebugSettingsDialog::slotSaveAs);
     connect(saveAs, &SaveToolButton::saveAsGroup, this, &KDebugSettingsDialog::slotSaveAsGroup);
 
-    mLoadToolButton = new LoadToolButton(this);
     mLoadToolButton->setObjectName(QStringLiteral("load_button"));
     buttonBox->addButton(mLoadToolButton, QDialogButtonBox::ActionRole);
     connect(mLoadToolButton, &LoadToolButton::loadFromFile, this, &KDebugSettingsDialog::slotLoad);
@@ -89,7 +93,9 @@ KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
 
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KDebugSettingsDialog::slotAccepted);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-    connect(buttonBox, &QDialogButtonBox::helpRequested, this, &KDebugSettingsDialog::slotHelpRequested);
+    auto helpMenu = new KHelpMenu(this, KAboutData::applicationData(), false);
+    buttonBox->button(QDialogButtonBox::Help)->setMenu(helpMenu->menu());
+
     connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &KDebugSettingsDialog::slotApply);
     connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KDebugSettingsDialog::slotRestoreDefault);
     mainLayout->addWidget(buttonBox);
@@ -174,11 +180,6 @@ void KDebugSettingsDialog::slotAccepted()
     }
 }
 
-void KDebugSettingsDialog::slotHelpRequested()
-{
-    QDesktopServices::openUrl(QUrl(QStringLiteral("https://doc.qt.io/qt-5/qloggingcategory.html#details")));
-}
-
 void KDebugSettingsDialog::slotApply()
 {
     saveInQtLogging();
@@ -214,7 +215,7 @@ void KDebugSettingsDialog::slotSaveAsGroup()
         const QString trimmedName = name.trimmed();
         if (!trimmedName.isEmpty()) {
             if (mLoadToolButton->groupNames().contains(trimmedName)) {
-                KMessageBox::error(this, i18n("\'%1\' is already used as a group name.\nPlease save as another name.", trimmedName));
+                KMessageBox::error(this, i18n("<b>\'%1\'</b> is already used as a group name.\nPlease save as another name.", trimmedName));
             } else {
                 if (!QDir().mkpath(groupPath)) {
                     qCWarning(KDEBUGSETTINGS_LOG) << "Unable to create folder: " << groupPath;
