@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -31,7 +31,6 @@ Q_SIGNALS:
 
 private:
     void slotAccepted();
-    void slotHelpRequested();
     void slotApply();
     void slotSaveAs();
     void slotLoad();
@@ -49,10 +48,10 @@ private:
     void slotManageGroup();
     KdeLoggingCategory::List mCategoriesList;
     KDebugSettingsLoadingCategories mLoggings;
-    QTabWidget *mTabWidget = nullptr;
-    KDEApplicationDebugSettingPage *mKdeApplicationSettingsPage = nullptr;
-    CustomDebugSettingsPage *mCustomSettingsPage = nullptr;
-    EnvironmentSettingsRulesPage *mEnvironmentSettingsRulesPage = nullptr;
-    CategoryWarning *mCategoryWarning = nullptr;
-    LoadToolButton *mLoadToolButton = nullptr;
+    QTabWidget *const mTabWidget;
+    KDEApplicationDebugSettingPage *const mKdeApplicationSettingsPage;
+    CustomDebugSettingsPage *const mCustomSettingsPage;
+    EnvironmentSettingsRulesPage *const mEnvironmentSettingsRulesPage;
+    CategoryWarning *const mCategoryWarning;
+    LoadToolButton *const mLoadToolButton;
 };
