@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -21,8 +21,10 @@
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
 
     QApplication app(argc, argv);
 
@@ -31,7 +33,7 @@ int main(int argc, char **argv)
                          QStringLiteral(KDEBUGSETTINGS_VERSION),
                          i18n("Configure debug settings"),
                          KAboutLicense::GPL_V2,
-                         i18n("(c) 2015-2021 kdebugsettings authors"));
+                         i18n("(c) 2015-%1 kdebugsettings authors", QStringLiteral("2023")));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
 
